## 广州民间借贷利率

接口：gz_index

描述：广州民间借贷利率

限量：不限量，一次可取全部指标全部历史数据

积分：用户需要积攒2000积分可调取，具体请参阅积分获取办法

数据来源：广州民间金融街

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| d10_rate | float | Y | 小额贷市场平均利率（十天） （单位：%，下同） |
| m1_rate | float | Y | 小额贷市场平均利率（一月期） |
| m3_rate | float | Y | 小额贷市场平均利率（三月期） |
| m6_rate | float | Y | 小额贷市场平均利率（六月期） |
| m12_rate | float | Y | 小额贷市场平均利率（一年期） |
| long_rate | float | Y | 小额贷市场平均利率（长期） |

接口用法

```python
pro = ts.pro_api()

df = pro.gz_index(start_date='20180101', end_date='20190401')
```

数据样例

```python
date  d10_rate  m1_rate  m3_rate  m6_rate  m12_rate  long_rate
0   20180327     12.00    19.20    19.20    12.77     14.40      12.00
```